@@ -1,9 +1,13 @@
+import argparse
 import pytest
 import tempfile
 from unittest import mock
 from .. import submission as submission_module
 from ..submission import DEFAULT_INGESTION_TYPE
-from ..scripts.submit_metadata_bundle import main as submit_metadata_bundle_main
+from ..scripts.submit_metadata_bundle import (
+    main as submit_metadata_bundle_main,
+    _setup_validate_related_options
+)
 from ..scripts import submit_metadata_bundle as submit_metadata_bundle_module
 from .testing_helpers import system_exit_expected, argparse_errors_muffled
 
@@ -37,7 +41,7 @@ def test_submit_metadata_bundle_script(keyfile):
         'server': None,
         # 'institution': None,
         # 'project': None,
-        'validate_only': False,
+        'validate_remote_only': False,
         'upload_folder': None,
         'no_query': False,
         'subfolders': False,
@@ -49,7 +53,7 @@ def test_submit_metadata_bundle_script(keyfile):
         'server': "some-server",
         # 'institution': "some-institution",
         # 'project': "some-project",
-        'validate_only': True,
+        'validate_remote_only': True,
         'upload_folder': None,
         'no_query': False,
         'subfolders': False,
@@ -72,7 +76,7 @@ def test_submit_metadata_bundle_script(keyfile):
         'server': "some-server",
         # 'institution': "some-institution",
         # 'project': "some-project",
-        'validate_only': False,
+        'validate_remote_only': False,
         'upload_folder': 'a-folder',
         'no_query': False,
         'subfolders': False,
@@ -102,7 +106,7 @@ def test_submit_metadata_bundle_script(keyfile):
         'server': "some-server",
         # 'institution': "some-institution",
         # 'project': "some-project",
-        'validate_only': True,
+        'validate_remote_only': True,
         'upload_folder': 'a-folder',
         'no_query': False,
         'subfolders': False,
@@ -136,7 +140,7 @@ def test_submit_metadata_bundle_script(keyfile):
         'server': "some-server",
         # 'institution': "some-institution",
         # 'project': "some-project",
-        'validate_only': True,
+        'validate_remote_only': True,
         'upload_folder': None,
         'no_query': True,
         'subfolders': True,
@@ -162,3 +166,63 @@ def _create_some_temporary_file() -> str:
     finally:
         some_file.close()
     return some_file.name
+
+
+def test_validation_options():
+
+    args = argparse.Namespace(submit=False,
+                              validate=False,
+                              validate_only=False,
+                              validate_remote=False,
+                              validate_remote_only=False,
+                              validate_local=False,
+                              validate_local_only=False)
+    _setup_validate_related_options(args)
+    # Note This is for admin users; for non-admin users it would be (TODO):
+    # assert (not args.validate_local and
+    #         not args.validate_local_only and
+    #         not args.validate_remote and
+    #         not args.validate_remote_only)
+    assert (not args.validate_local and
+            not args.validate_local_only and
+            not args.validate_remote and
+            not args.validate_remote_only)
+
+    args = argparse.Namespace(submit=False,
+                              validate=True,
+                              validate_only=False,
+                              validate_remote=False,
+                              validate_remote_only=False,
+                              validate_local=False,
+                              validate_local_only=False)
+    _setup_validate_related_options(args)
+    assert (args.validate_local and
+            not args.validate_local_only and
+            args.validate_remote and
+            args.validate_remote_only)
+
+    args = argparse.Namespace(submit=False,
+                              validate=False,
+                              validate_only=True,
+                              validate_remote=False,
+                              validate_remote_only=False,
+                              validate_local=False,
+                              validate_local_only=False)
+    _setup_validate_related_options(args)
+    assert (args.validate_local and
+            not args.validate_local_only and
+            not args.validate_remote and
+            args.validate_remote_only)
+
+    args = argparse.Namespace(submit=False,
+                              validate=False,
+                              validate_only=False,
+                              validate_remote=False,
+                              validate_remote_only=False,
+                              validate_local=True,
+                              validate_local_only=False)
+    _setup_validate_related_options(args)
+    assert (args.validate_local and
+            not args.validate_local_only and
+            not args.validate_remote and
+            not args.validate_remote_only)
